ATel #12499: ULTRASPEC observations of SWIFT J1858.6-0814

Outside GCN IAUCs Other ATel on Twitter and Facebook ATELstream ATel Community Site | Post | Search | Policies Credential | Feeds | Email 4 May 2020; 09:18 UT | This space for free for your conference.

[ Previous | Next | ADS ] # ULTRASPEC observations of SWIFT J1858.6-0814 ATel #12499; K. M. Rajwade (Univ. of Manchester), V. S. Dhillon (Univ. of Sheffield), P. Gandhi (Univ. of Southampton), J. A. Paice (Univ. of Southampton), M. Kennedy (Univ. of Manchester), C. J. Clark (Univ. of Manchester), J. Wild (Univ. of Sheffield), S. Littlefair (Univ. of Sheffield), T. Marsh (Univ. of Warwick) on 12 Feb 2019; 16:41 UT Credential Certification: Kaustubh Rajwade (rkaustubh10@gmail.com) Subjects: Optical, Binary, Black Hole, Neutron Star, Transient Referred to by ATel #: 12512 Tweet Swift J1858.6-0814 is a Galactic X-ray transient discovered on 2018 October 25 (MJD 58416) (ATel #12151) and has been the subject of much multi-wavelength follow-up. It has displayed large amplitude flaring in X-rays and optical, as well as prominent reflection and absorption X-ray signatures, and it has been detected in the radio. These characteristics have led to comparisons being drawn with other Galactic microquasars such as V404 Cyg (ATel#12158, #12160, #12163, #12164, #12167, #12180, #12184, #12186, #12197, #12220). Since the last high time-resolution optical follow-up of Swift J1858.6-0814 (ATel#12186, ATel#12197), further multi-wavelength follow-up was hampered due to the proximity of the source to the Sun. On 2019 February 10 at 22:53UT, we observed the source for 2 minutes in the SDSS r' filter using the ULTRASPEC photometer (Dhillon et al. 2014, MNRAS, 444, 4009) mounted on the 2.4 m Thai National Telescope. The target was at an elevation of 20 degrees and was observed during morning twilight. We detected the source, with an r'-band magnitude of 17.28 +/- 0.11 computed from the average of 5 nearby bright stars from the Pan-STARRs (Flewelling et al. 2019) catalogue. This indicates that the source is still in an active phase with the optical magnitude comparable to that observed in November last year. We attach a figure of the Pan-STARRS r'-band image of the field (left) along with image from our ULTRASPEC observing run with the source marked in both the images. Continued multi-wavelength monitoring of the source is planned and encouraged. ULTRASPEC image of our 2-min exposure | Related
13563 | NICER and NuSTAR detections of Type I bursts and periodic dips in Swift J1858.6-0814
13536 | NICER detection of flux increase and spectral state change in Swift 1858.6-0814
13455 | MAXI/GSC detection of a probable new soft X-ray transient MAXI J1857-086 or renewed activity of Swift J1858.6-0814
13255 | Transient Activity in recent GPS observations
13223 | Swift J1845.7-0037: Lulin optical observation
13222 | Revised SED of the Probable Infrared Counterpart to Swift J1845.7-0037
13220 | Near-Infrared archival data on 2MASS J18455462-0039341 / Swift J1845.7-0037
13219 | Swift J1845.7-0037: Comparison of X-ray and optical positions
13218 | 2MASS J18455462-0039341 / Swift J1845.7-0037 is a double star
13214 | Erratum to ATEL#13208
13211 | Evidence of a B Star Counterpart to Swift J1845.7-0037
13208 | A descriptive title
13195 | Swift J1845.7-0037: 199s period detection, possible BeXRB?
13191 | MAXI J1847-004: Swift observation and identification with Swift J1845.7-0037
13189 | MAXI/GSC discovery of a new hard X-ray transient MAXI J1847-004
13037 | Insight-HXMT monitoring of the Type-C QPO in the black hole candidate EXO 1846-031
13036 | Insight-HXMT detection of the hard-to-soft state transition in the black hole candidate EXO 1846-031
13012 | Disk Reflection and Winds in a NuSTAR Observation of the Black Hole Candidate EXO 1846-031
12992 | MeerKAT detection of EXO 1846-031 at 1.3 GHz
12991 | ZTF limits on optical emission from EXO 1846-031
12977 | VLA radio detection of the black hole candidate X-ray binary EXO 1846-031
12976 | NICER detection of QPOs from EXO 1846-031
12969 | Localization of EXO 1846-031 by Swift/XRT
12968 | MAXI/GSC detection of renewed activity of the black hole candidate EXO 1846-031 after 34 years
12881 | Detection of optical P-Cygni profiles in Swift J1858.6-0814
12704 | INTEGRAL's detection of two Galactic X-ray transient sources: SWIFT J1858.6-0814 and 4U 1901+014
12684 | Possible discovery of a cyclotron line in 4U 1901+03 with NuSTAR
12512 | NuSTAR shows continued X-ray activity of Swift J1858.6-0814 in an unusual spectral state
12499 | ULTRASPEC observations of SWIFT J1858.6-0814
12498 | MAXI/GSC detection of the outburst from binary X-ray pulsar 4U 1901+03
12220 | Significant Intrinsic Absorption in Swift J1858.6-0814
12197 | Blue Oscillations and Rapid Red Flares in Swift J1858.6-0814 Observed with ULTRACAM/NTT
12186 | More optical follow-up of Swift J1858.6-0814
12184 | AMI-LA radio observations of the galactic X-ray transient Swift J1858.6-0814
12180 | Optical observations of the rapidly varying newly discovered transient Swift J1858.6-0814
12167 | INTEGRAL detection of the X-ray transient Swift J1858.6-0814
12164 | Swift J1858.6-0814: Localization and variability of the optical counterpart
12163 | MAXI/GSC observations of the X-ray transient Swift J1858.6-0814
12160 | Swift J1858.6-0814: Swift XRT and UVOT localization
12158 | Initial NICER observation of the new X-ray transient Swift J1858.6-0814
12151 | Swift reports the detection of a new galactic transient source Swift J1858.6-0814